@@ -2,7 +2,7 @@
 /**
  * Trean application API
  *
- * Copyright 2002-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (BSD). If you
  * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
@@ -12,7 +12,7 @@
 
 /* Determine the base directories. */
 if (!defined('TREAN_BASE')) {
-    define('TREAN_BASE', __DIR__ . '/..');
+    define('TREAN_BASE', realpath(__DIR__ . '/..'));
 }
 
 if (!defined('HORDE_BASE')) {
@@ -21,7 +21,7 @@ if (!defined('HORDE_BASE')) {
     if (file_exists(TREAN_BASE . '/config/horde.local.php')) {
         include TREAN_BASE . '/config/horde.local.php';
     } else {
-        define('HORDE_BASE', TREAN_BASE . '/..');
+        define('HORDE_BASE', realpath(TREAN_BASE . '/..'));
     }
 }
 
@@ -33,7 +33,7 @@ class Trean_Application extends Horde_Registry_Application
 {
     /**
      */
-    public $version = 'H5 (1.0.3)';
+    public $version = 'H5 (1.1.1)';
 
     /**
      * Global variables defined:
@@ -54,6 +54,8 @@ class Trean_Application extends Horde_Registry_Application
             throw new Horde_Exception('The Content_Tagger class could not be found. Make sure the Content application is installed.');
         }
 
+        $GLOBALS['injector']->bindFactory('Trean_TagBrowser', 'Trean_Factory_TagBrowser', 'create');
+
         // Set the timezone variable.
         $GLOBALS['registry']->setTimeZone();
 
@@ -82,6 +84,7 @@ class Trean_Application extends Horde_Registry_Application
     public function menu($menu)
     {
         $menu->add(Horde::url('browse.php'), _("_Browse"), 'trean-browse', null, null, null, basename($_SERVER['PHP_SELF']) == 'index.php' ? 'current' : null);
+        $menu->add(Horde::url('data.php'), _("_Import"), 'horde-data');
     }
 
     /**
@@ -115,4 +118,12 @@ class Trean_Application extends Horde_Registry_Application
         }
     }
 
+    /**
+     */
+    public function cleanupData()
+    {
+        $GLOBALS['import_step'] = 1;
+        return Horde_Data::IMPORT_FILE;
+    }
+
 }
